Installation of easy-vault project
==================================

To install the latest released version of the
easy-vault project into your active Python environment:

      $ pip install easy-vault

This will also install any prerequisite Python packages.

For more details and alternative ways to install, see
[Installation](https://easy-vault.readthedocs.io/en/stable/intro.html#installation).
